@@ -6,37 +6,37 @@
 # \description{
 #  @classhierarchy
 #
-#  This class represents a normalization method that corrects for 
+#  This class represents a normalization method that corrects for
 #  GC-content effects on copy-number chip-effect estimates.
 # }
-# 
-# @synopsis 
+#
+# @synopsis
 #
 # \arguments{
 #   \item{dataSet}{A @see "SnpChipEffectSet".}
-#   \item{...}{Additional arguments passed to the constructor of 
+#   \item{...}{Additional arguments passed to the constructor of
 #     @see "ChipEffectTransform".}
 #   \item{target}{(Optional) A @character string or a @function
 #     specifying what to normalize toward.}
 #   \item{subsetToFit}{The units from which the normalization curve should
 #     be estimated.  If @NULL, all are considered.}
-#   \item{onMissing}{Specifies how to normalize units for which the 
+#   \item{onMissing}{Specifies how to normalize units for which the
 #     GC contents are unknown.}
 #   \item{shift}{An optional amount the data points should be shifted
 #      (translated).}
 # }
 #
 # \section{Fields and Methods}{
-#  @allmethods "public"  
+#  @allmethods "public"
 # }
-# 
+#
 # \details{
-#   For SNPs, the normalization function is estimated based on the total 
+#   For SNPs, the normalization function is estimated based on the total
 #   chip effects, i.e. the sum of the allele signals.  The normalizing
 #   is done by rescale the chip effects on the intensity scale such that
 #   the mean of the total chip effects are the same across samples for
 #   any given GC content.  For allele-specific estimates, both alleles
-#   are always rescaled by the same amount.  Thus, when normalizing  
+#   are always rescaled by the same amount.  Thus, when normalizing
 #   allele-specific chip effects, the total chip effects is change, but not
 #   the relative allele signal, e.g. the allele B frequency.
 # }
@@ -68,7 +68,7 @@ setConstructorS3("AdditiveCovariatesNormalization", function(dataSet=NULL, ...,
       # Validate each element
       for (kk in seq_along(target)) {
         if (!is.function(target[[kk]])) {
-          throw("One element in 'target' is not a function: ", 
+          throw("One element in 'target' is not a function: ",
                                              class(target[[kk]])[1]);
         }
       }
@@ -94,12 +94,12 @@ setConstructorS3("AdditiveCovariatesNormalization", function(dataSet=NULL, ...,
 
   # Argument 'shift':
   shift <- Arguments$getDouble(shift, disallow=c("NA", "NaN", "Inf"));
- 
+
   # Argument 'onMissing':
   onMissing <- match.arg(onMissing);
 
 
-  extend(ChipEffectTransform(dataSet, ...), "AdditiveCovariatesNormalization", 
+  extend(ChipEffectTransform(dataSet, ...), "AdditiveCovariatesNormalization",
     .subsetToFit = subsetToFit,
     "cached:.target" = target,
     .onMissing = onMissing,
@@ -246,7 +246,8 @@ setMethodS3("getSubsetToFit", "AdditiveCovariatesNormalization", function(this,
   types <- getUnitTypes(cdf, verbose=less(verbose,1));
   verbose && print(verbose, table(types));
   units <- which(types == 2 | types == 5);
-  rm(types);
+  # Not needed anymore
+  types <- NULL;
   verbose && cat(verbose, "units:");
   verbose && str(verbose, units);
   verbose && exit(verbose);
@@ -264,7 +265,8 @@ setMethodS3("getSubsetToFit", "AdditiveCovariatesNormalization", function(this,
     units <- units[keep];
     verbose && printf(verbose, "Number of SNP/CN units without finite covariates: %d out of %d (%.1f%%)\n", sum(!keep), length(keep), 100*sum(!keep)/length(keep));
     verbose && exit(verbose);
-    rm(keep, X);
+    # Not needed anymore
+    keep <- X <- NULL;
   }
 
 
@@ -283,7 +285,7 @@ setMethodS3("getSubsetToFit", "AdditiveCovariatesNormalization", function(this,
         # Get the genome information (throws an exception if missing)
         gi <- getGenomeInformation(cdf);
         verbose && print(verbose, gi);
-  
+
         # Identify units to be excluded
         if (subsetToFit == "-X") {
           subset <- getUnitsOnChromosomes(gi, 23, .checkArgs=FALSE);
@@ -292,13 +294,13 @@ setMethodS3("getSubsetToFit", "AdditiveCovariatesNormalization", function(this,
         } else if (subsetToFit == "-XY") {
           subset <- getUnitsOnChromosomes(gi, 23:24, .checkArgs=FALSE);
         }
-  
+
         verbose && cat(verbose, "Units to exclude: ");
         verbose && str(verbose, subset);
-  
+
         # The units to keep
         subset <- setdiff(seq_len(nbrOfUnits), subset);
-  
+
         verbose && cat(verbose, "Units to include: ");
         verbose && str(verbose, subset);
 
@@ -307,7 +309,8 @@ setMethodS3("getSubsetToFit", "AdditiveCovariatesNormalization", function(this,
       }
 
       subsetToFit <- subset;
-      rm(subset);
+      # Not needed anymore
+      subset <- NULL;
 
       verbose && exit(verbose);
     }
@@ -331,14 +334,16 @@ setMethodS3("getSubsetToFit", "AdditiveCovariatesNormalization", function(this,
     for (ee in seq_len(ncol(X))) {
       extremeUnits <- c(extremeUnits, which.min(X[,ee]), which.max(X[,ee]));
     }
-    rm(X);
+    # Not needed anymore
+    X <- NULL;
 
     keep <- c(keep, extremeUnits);
     keep <- unique(keep);
 
     # Now filter
     units <- units[keep];
-    rm(keep);
+    # Not needed anymore
+    keep <- NULL;
   }
 
   # Sort units
@@ -381,7 +386,8 @@ setMethodS3("getTargetFunctions", "AdditiveCovariatesNormalization", function(th
       targetType <- attr(target, "targetType");
       if (!is.null(targetType))
         target <- targetType;
-      rm(targetType);
+      # Not needed anymore
+      targetType <- NULL;
     }
   }
 
@@ -396,7 +402,8 @@ setMethodS3("getTargetFunctions", "AdditiveCovariatesNormalization", function(th
     # Infer the number of covariates
     X <- getCovariates(this, units=1:5);
     nbrOfCovariates <- ncol(X);
-    rm(X);
+    # Not needed anymore
+    X <- NULL;
 
     if (identical(targetType, "zero")) {
       target <- rep(list(function(...) log2(2200)), nbrOfCovariates);
@@ -410,7 +417,7 @@ setMethodS3("getTargetFunctions", "AdditiveCovariatesNormalization", function(th
     this$.target <- target;
     force <- FALSE;
     verbose && exit(verbose);
-  } 
+  }
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -421,7 +428,8 @@ setMethodS3("getTargetFunctions", "AdditiveCovariatesNormalization", function(th
     ces <- getInputDataSet(this);
     verbose && enter(verbose, "Getting average signal across arrays");
     ceR <- getAverageFile(ces, force=force, verbose=less(verbose));
-    rm(ces); # Not needed anymore
+    # Not needed anymore
+    ces <- NULL; # Not needed anymore
     verbose && exit(verbose);
 
     # Garbage collect
@@ -435,7 +443,8 @@ setMethodS3("getTargetFunctions", "AdditiveCovariatesNormalization", function(th
 
     # Get target signals for SNPs
     yR <- extractTheta(ceR, units=units, verbose=less(verbose, 5));
-    rm(ceR); # Not needed anymore
+    # Not needed anymore
+    ceR <- NULL; # Not needed anymore
     verbose && cat(verbose, "(Allele-specific) thetas:");
     verbose && str(verbose, yR);
 
@@ -462,16 +471,17 @@ setMethodS3("getTargetFunctions", "AdditiveCovariatesNormalization", function(th
       verbose && cat(verbose, "Summary of shifted signals (on the intensity scale):");
       verbose && summary(verbose, yR);
     }
-    
+
     yR <- log2(yR);
     verbose && cat(verbose, "Signals:");
     verbose && str(verbose, yR);
     verbose && cat(verbose, "Summary of signals (on the log2 scale):");
     verbose && summary(verbose, yR);
-    
+
     # Get PCR fragment lengths for these
     X <- getCovariates(this, units=units, verbose=less(verbose,5));
-    rm(units); # Not needed anymore
+    # Not needed anymore
+    units <- NULL; # Not needed anymore
     verbose && cat(verbose, "Annotation data covariates:");
     verbose && str(verbose, X);
     verbose && cat(verbose, "Summary of covariates:");
@@ -518,17 +528,20 @@ setMethodS3("getTargetFunctions", "AdditiveCovariatesNormalization", function(th
       fit <- lowess(X[ok,ee], yR[ok]);
       class(fit) <- "lowess";
 
-      rm(ok);
+      # Not needed anymore
+      ok <- NULL;
 
       fits[[ee]] <- fit;
 
-      rm(fit);
+      # Not needed anymore
+      fit <- NULL;
 
       verbose && exit(verbose);
     } # for (ee ...)
 
     # Remove as many promises as possible
-    rm(target, nbrOfCovariates, allCovariates, X, hasX, yR, okYR);
+    # Not needed anymore
+    target <- nbrOfCovariates <- allCovariates <- X <- hasX <- yR <- okYR <- NULL;
 
     # Create a target prediction function for each covariate
     fcns <- vector("list", length(fits));
@@ -545,7 +558,8 @@ setMethodS3("getTargetFunctions", "AdditiveCovariatesNormalization", function(th
     verbose && print(verbose, gc);
 
     target <- fcns;
-    rm(fcns);
+    # Not needed anymore
+    fcns <- NULL;
     this$.target <- target;
     force <- FALSE;
 
@@ -570,9 +584,9 @@ setMethodS3("getTargetFunctions", "AdditiveCovariatesNormalization", function(th
 # @synopsis
 #
 # \arguments{
-#   \item{...}{Additional arguments passed to 
+#   \item{...}{Additional arguments passed to
 #     @see "aroma.light::normalizeFragmentLength" (only for advanced users).}
-#   \item{force}{If @TRUE, data already normalized is re-normalized, 
+#   \item{force}{If @TRUE, data already normalized is re-normalized,
 #       otherwise not.}
 #   \item{verbose}{See @see "R.utils::Verbose".}
 # }
@@ -625,11 +639,12 @@ setMethodS3("process", "AdditiveCovariatesNormalization", function(this, ..., fo
   types <- getUnitTypes(cdf, verbose=less(verbose,1));
   verbose && print(verbose, table(types));
   subsetToUpdate <- which(types == 2 | types == 5);
-  rm(types);
+  # Not needed anymore
+  types <- NULL;
   verbose && cat(verbose, "subsetToUpdate:");
   verbose && str(verbose, subsetToUpdate);
   verbose && exit(verbose);
-  
+
 
   verbose && enter(verbose, "Identifying the subset used to fit normalization function(s)");
   # Get subset to fit
@@ -646,7 +661,7 @@ setMethodS3("process", "AdditiveCovariatesNormalization", function(this, ..., fo
   # Get (and create) the output path
   path <- getPath(this);
 
-  
+
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Normalize each array
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -662,7 +677,7 @@ setMethodS3("process", "AdditiveCovariatesNormalization", function(this, ..., fo
 
     filename <- getFilename(ce);
     pathname <- filePath(path, filename);
-    if (isFile(pathname)) {
+    if (!force && isFile(pathname)) {
       verbose && cat(verbose, "Already normalized. Skipping.");
       ceN <- fromFile(ce, pathname);
 
@@ -691,7 +706,7 @@ setMethodS3("process", "AdditiveCovariatesNormalization", function(this, ..., fo
 #    }
 
     if (is.null(X)) {
-      # For the subset to be fitted, get PCR fragment lengths (for all covariates) 
+      # For the subset to be fitted, get PCR fragment lengths (for all covariates)
       X <- getCovariates(this, units=subsetToUpdate, verbose=less(verbose,5));
       verbose && summary(verbose, X);
 
@@ -753,15 +768,16 @@ setMethodS3("process", "AdditiveCovariatesNormalization", function(this, ..., fo
 
     verbose && cat(verbose, "Log2 signals:");
     verbose && str(verbose, y);
-    yN <- normalizeFragmentLength(y, fragmentLengths=X, 
-                    targetFcns=targetFcns, subsetToFit=subset, 
+    yN <- normalizeFragmentLength(y, fragmentLengths=X,
+                    targetFcns=targetFcns, subsetToFit=subset,
                     onMissing=onMissing, ...);
     verbose && cat(verbose, "Normalized log2 signals:");
     verbose && summary(verbose, yN);
 
     # Normalization scale factor for each unit (on the log2 scale)
     rho <- y-yN;
-    rm(y,yN);
+    # Not needed anymore
+    y <- yN <- NULL;
     # On the intensity scale
     rho <- 2^rho;
     verbose && cat(verbose, "Normalization scale factors:");
@@ -774,7 +790,8 @@ setMethodS3("process", "AdditiveCovariatesNormalization", function(this, ..., fo
     ok <- which(is.finite(rho));
     verbose && str(verbose, ok);
     theta[ok,] <- theta[ok,]/rho[ok];
-    rm(ok, rho);
+    # Not needed anymore
+    ok <- rho <- NULL;
 
     verbose && cat(verbose, "Normalized thetas:");
     verbose && str(verbose, theta);
@@ -782,9 +799,13 @@ setMethodS3("process", "AdditiveCovariatesNormalization", function(this, ..., fo
 
     verbose && exit(verbose);
 
+    # Write to a temporary file (allow rename of existing one if forced)
+    isFile <- (force && isFile(pathname));
+    pathnameT <- pushTemporaryFile(pathname, isFile=isFile, verbose=verbose);
+
     # Create CEL file to store results, if missing
     verbose && enter(verbose, "Creating CEL file for results, if missing");
-    ceN <- createFrom(ce, filename=pathname, path=NULL, verbose=less(verbose));
+    ceN <- createFrom(ce, filename=pathnameT, path=NULL, verbose=less(verbose));
     verbose && exit(verbose);
 
     # Carry over parameters too.  AD HOC for now. /HB 2007-01-07
@@ -802,14 +823,19 @@ setMethodS3("process", "AdditiveCovariatesNormalization", function(this, ..., fo
     ok <- which(is.finite(cellMatrixMap));
     cells <- cellMatrixMap[ok];
     data <- theta[ok];
-    rm(ok, theta);
+    # Not needed anymore
+    ok <- theta <- NULL;
 
     verbose2 <- -as.integer(verbose) - 5;
-    pathname <- getPathname(ceN);   
-    updateCel(pathname, indices=cells, intensities=data, verbose=verbose2);
-    rm(cells, data);
+    pathnameN <- getPathname(ceN);
+    updateCel(pathnameN, indices=cells, intensities=data, verbose=verbose2);
+    # Not needed anymore
+    cells <- data <- NULL;
     verbose && exit(verbose);
 
+    # Rename temporary file
+    pathname <- popTemporaryFile(pathnameT, verbose=verbose);
+
     # Garbage collect
     gc <- gc();
     verbose && print(verbose, gc);
@@ -821,12 +847,15 @@ setMethodS3("process", "AdditiveCovariatesNormalization", function(this, ..., fo
   outputSet <- getOutputDataSet(this, verbose=less(verbose,5));
 
   verbose && exit(verbose);
-  
+
   outputSet;
 })
 
 ############################################################################
 # HISTORY:
+# 2013-06-01
+# o Argument process(..., force=TRUE) for AdditiveCovariatesNormalization
+#   did not force reprocessing.
 # 2009-03-22
 # o Generalized by creating abstract getCovariates() method.
 # o Created from FragmentLengthNormalization.R.
