@@ -740,7 +740,7 @@ setMethodS3("getCellIndices", "AffymetrixCdfFile", function(this, units=NULL, ..
   }
 
   # This is a trick to store either to memory or file cache
-  key <- digest2(key);
+  key <- getChecksum(key);
   if (!force) {
     # (a) Check memory cache
     res <- this$.cellIndices[[key]];
@@ -790,7 +790,8 @@ setMethodS3("getCellIndices", "AffymetrixCdfFile", function(this, units=NULL, ..
   verbose && exit(verbose);
 
   units <- units0;
-  rm(units0);
+  # Not needed anymore
+  units0 <- NULL;
 
   # Garbage collect
   gc <- gc();
@@ -1142,7 +1143,8 @@ setMethodS3("identifyCells", "AffymetrixCdfFile", function(this, indices=NULL, f
 
   if (is.null(indices)) {
     indices <- other;
-    rm(other);
+    # Not needed anymore
+    other <- NULL;
   } else {
     if (getFraction) {
       # Get the fraction from the already filtered cell indices
