@@ -211,7 +211,8 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
   verbose && cat(verbose, "Number of cells per unit:");
   verbose && summary(verbose, nbrOfCellsPerUnit);
 
-  rm(cdfLite); # Not needed anymore
+  # Not needed anymore
+  cdfLite <- NULL; # Not needed anymore
 
   # Total number of cells in CDF
   nbrOfCells <- sum(nbrOfCellsPerUnit);
@@ -323,7 +324,8 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
                     qcUnitLengths=qcUnitLengths, unitLengths=unitLengths,
                                                         verbose=verbose2);
   # Not needed anymore
-  rm(destHeader, unitNames, qcUnitLengths, unitLengths);
+  # Not needed anymore
+  destHeader <- unitNames <- qcUnitLengths <- unitLengths <- NULL;
 
   # Garbage collect
   gc <- gc();
@@ -346,7 +348,8 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
 
   # Write QC units
   writeCdfQcUnits(con=con, destQcUnits, verbose=verbose2);
-  rm(destQcUnits); # Not needed anymore
+  # Not needed anymore
+  destQcUnits <- NULL; # Not needed anymore
 
   # Garbage collect
   gc <- gc();
@@ -460,11 +463,13 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
 
     # Write regular units
     writeCdfUnits(con=con, srcUnits, verbose=verbose2);
-    rm(srcUnits, units); # Not needed anymore
+    # Not needed anymore
+    srcUnits <- units <- NULL; # Not needed anymore
 
     count <- count + 1;
   } # while (length(unitsToDo) > 0)
-  rm(unitsToDo, head, fields, count);
+  # Not needed anymore
+  unitsToDo <- head <- fields <- count <- NULL;
 
   # Garbage collect
   gc <- gc();
@@ -515,7 +520,8 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
     if (!identical(udcells, 1:1)) {
       throw("Failed to create a valid unique-cell CDF: The cell indices are not contiguous: ", paste(udcells, collapse=", "));
     }
-    rm(cells, udcells);
+    # Not needed anymore
+    cells <- udcells <- NULL;
   }
   verbose && exit(verbose);
 
@@ -673,9 +679,11 @@ setMethodS3("getUnitGroupCellMapWithUnique", "AffymetrixCdfFile", function(this,
   })
   # (2) Map (unit, group)_unique to (unit, group)_main
   rr <- match(ugHashcode[[1]], ugHashcode[[2]]);
-  rm(ugHashcode);
+  # Not needed anymore
+  ugHashcode <- NULL;
   mergedMap <- cbind(ugcMap[[1]], cellM=ugcMap[[2]][rr,"cell"]);
-  rm(ugcMap);
+  # Not needed anymore
+  ugcMap <- NULL;
 
   mergedMap;
 }, protected=TRUE)
