@@ -7,7 +7,7 @@ setMethodS3("getCdfBin", "DChipDcpSet", function(this, force=FALSE, ...) {
 
     # Sanity check by searching for a matching CDF.bin file
     pattern <- sprintf("%s.*.cdf.bin", chipType);
-    pathnames <- findAnnotationDataByChipType(chipType, 
+    pathnames <- findAnnotationDataByChipType(chipType,
                                     pattern=pattern, firstOnly=FALSE);
     if (length(pathnames) == 0) {
       throw("Cannot infer full chip type. Failed to locate a CDF.bin file.");
@@ -52,7 +52,7 @@ setMethodS3("exportTotalAndFracB", "DChipDcpSet", function(this, ..., overwrite=
     pushState(verbose);
     on.exit(popState(verbose));
   }
- 
+
 
   verbose && enter(verbose, "Exporting (total,fracB) data from ", class(this)[1]);
   dataSet <- getFullName(this);
@@ -76,7 +76,8 @@ setMethodS3("exportTotalAndFracB", "DChipDcpSet", function(this, ..., overwrite=
   verbose && cat(verbose, "Chip type: ", chipType);
 
   units <- mapToUnitNamesFile(cdfBin, cdf=cdf, verbose=less(verbose, 10));
-  rm(cdf);
+  # Not needed anymore
+  cdf <- NULL;
   verbose && cat(verbose, "Units in output files:");
   verbose && str(verbose, units);
 
@@ -105,12 +106,14 @@ setMethodS3("exportTotalAndFracB", "DChipDcpSet", function(this, ..., overwrite=
     }
 
     verbose && enter(verbose, "Allocating (temporary) output file");
-    pathnameT <- pushTemporaryFile(pathname, verbose=verbose);
+    # (allow rename of existing one if forced)
+    isFile <- (overwrite && isFile(pathname));
+    pathnameT <- pushTemporaryFile(pathname, isFile=isFile, verbose=verbose);
 
     asb <- AromaUnitSignalBinaryFile$allocate(pathnameT, nbrOfRows=nbrOfUnits(cdf), platform=platform, chipType=chipType);
     verbose && print(verbose, asb);
     verbose && exit(verbose);
-  
+
 
     verbose && enter(verbose, "Reading data from DCP file");
     data <- extractTheta(ce, drop=TRUE, verbose=verbose);
@@ -127,11 +130,14 @@ setMethodS3("exportTotalAndFracB", "DChipDcpSet", function(this, ..., overwrite=
       srcDataSet=dataSet,
       srcFullName=getFullName(ce),
       srcFilename=getFilename(ce),
-      srcChecksum=getChecksum(ce) 
+      srcChecksum=getChecksum(ce)
     );
     writeFooter(asb, footer);
     verbose && exit(verbose);
 
+    # Not needed anymore
+    data <- asb <- footer <- NULL;
+
     # Rename temporary file
     pathname <- popTemporaryFile(pathnameT, verbose=verbose);
 
@@ -155,7 +161,7 @@ setMethodS3("exportTotalAndFracB", "DChipDcpSet", function(this, ..., overwrite=
 # HISTORY:
 # 2010-01-06
 # o CLEAN UP: No need for assign NAs when allocating new files; this is now
-#   always the default way (in aroma.core v1.4.1). 
+#   always the default way (in aroma.core v1.4.1).
 # 2009-02-13
 # o Added exportTotalFracB().
 # o Added getCdfBin().
