@@ -405,7 +405,8 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
   design <- params$design;
   nProbes <- params$nProbes;
   meanTrim <- params$meanTrim;
-  rm(params);
+  # Not needed anymore
+  params <- NULL;
 
 
   # ------------------------------------------------------
@@ -463,10 +464,12 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
       next;
     }
 
-    # Check already here if there is already a tempory output file.  This
+    # Check already here if there is already a temporary output file.  This
     # may be a left over from a interrupted previous run, or the fact that
     # the array is processed by another session elsewhere. /HB
-    pathnameT <- pushTemporaryFile(pathname, verbose=verbose);
+    # (allow rename of existing one if forced)
+    isFile <- (force && isFile(pathname));
+    pathnameT <- pushTemporaryFile(pathname, isFile=isFile, verbose=verbose);
 
     matScoreNeg <- matScorePos <- outputList <- vector("list", nbrOfUnits);
     names(outputList) <- unitNames;
@@ -484,7 +487,8 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
     dataList <- readUnits(dsII, units=cdfCellsList, verbose=verbose);
     # ...instead of rereading all again
     ## dataList <- readUnits(dsII, units=units, stratifyBy="pm", verbose=verbose);
-    rm(dsII);
+    # Not needed anymore
+    dsII <- NULL;
     verbose && exit(verbose);
 
     dataList <- base::lapply(dataList, FUN=function(u) {
@@ -529,7 +533,8 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
     } # for (jj ...)
 
     # Memory cleanup
-    rm(dataList);
+    # Not needed anymore
+    dataList <- NULL;
 
     verbose && exit(verbose);
 
@@ -551,7 +556,8 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
       verbose && enter(verbose, "Calculating null distributions for controls and treatments in parallel");
       nullX <- cbind(neg=matScoreNeg, pos=matScorePos);
       nullDists <- calcNullDists(chr, pos, nullX);
-      rm(chr, pos, nullX);
+      # Not needed anymore
+      chr <- pos <- nullX <- NULL;
       verbose && str(verbose, nullDists);
       verbose && exit(verbose);
 
@@ -559,7 +565,8 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
       verbose && printf(verbose, "Scale factor: %.4g\n", scaleFactor);
       # Sanity check
       stopifnot(is.finite(scaleFactor));
-      rm(nullDists);
+      # Not needed anymore
+      nullDists <- NULL;
       verbose && exit(verbose);
     } else {
       scaleFactor <- 1;
@@ -571,7 +578,8 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     verbose && enter(verbose, "Calculating MAT scores (on intensity scale)");
     matScores <- matScorePos - scaleFactor*matScoreNeg;
-    rm(matScoreNeg, matScorePos);
+    # Not needed anymore
+    matScoreNeg <- matScorePos <- NULL;
     # ...on the intensity scale
     matScores <- 2^matScores;
     verbose && str(verbose, matScores);
@@ -587,7 +595,7 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
     verbose && enter(verbose, "Storing results");
 
     # Always validate the output file just before writing
-    pathnameT <- Arguments$getWritablePathname(pathnameT, mustNotExist=TRUE);
+    pathnameT <- Arguments$getWritablePathname(pathnameT, mustNotExist=!force);
 
     # Create CEL file to store results, if missing
     verbose && enter(verbose, "Creating CEL file for results, if missing");
@@ -604,7 +612,8 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
     # Rename temporary file
     pathname <- popTemporaryFile(pathnameT, verbose=verbose);
 
-    rm(filename, pathname, pathnameT);
+    # Not needed anymore
+    filename <- pathname <- pathnameT <- NULL;
     verbose && exit(verbose);
 
 
@@ -612,7 +621,8 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
     # Next column in design matrix
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     # Memory cleanup
-    rm(matScores);
+    # Not needed anymore
+    matScores <- NULL;
 
     # Garbage collect
     gc <- gc();
@@ -622,7 +632,8 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
   } # for (ii ...)
 
   # Clean up
-  rm(cellsList, allInds, acpData);
+  # Not needed anymore
+  cellsList <- allInds <- acpData <- NULL;
 
   outputDataSet <- getOutputDataSet(this, force=TRUE);
 
